@@ -28,7 +28,7 @@ INVALID_CHARS = {
     "da": r"[^a-zA-ZÆØÅæøåÉÈÊÓÒÂÔéèêóòâôç]",
     "fi": r"[^a-zA-ZÅÄÖåäöŠšŽž]",
     "no": r"[^a-zA-ZÆØÅæøåÉÈÊÓÒÂÔéèêóòâôç]",
-    "ru": r"[^АаБбВвГгДдЕеЁёЖжЗзИиЙйКкЛлМмНнОоПпСсТтУуФфХхЦцЧчШшЩщЪъЫыЬьЭэЮюЯя]",
+    "ru": r"[^А-Яа-яЁё]",
 }
 
 PERCENT_WORD = {
